Editor Test: ViewSource Plugin

Content before the editors.

# ViewSource Plugin details

1. The ViewSource plugin provides an extra button on the toolbar to allow switching the editor from WSYIWYG editing to into HTML source mode editing in the browser. This plugin is particularly useful when needing to tweak generated HTML source.
2. The mode can also be toggled by entering the key command: CTRL-SHIFT-F12 in the editor pane.
3. When it toggled it makes the edit area either a textarea if editing is enabled, or a readonly TEXTAREA node if it is not editable.
4. The plugin is aware of the FullScreen plugin, and when present will make sure that FullScreen knows which node to make 'full'.
5. The View Source adds in basic comment and script tag stripping by default (to help avoid XSS) attacks in code. These can be disabled, but it is not recommended.
6. While in view source mode, all other menu bar plugins are disabled.

## Things to test:

1. Verify that clicking the View Source icon highlights the button appropriately and toggles the view source mode on.
2. Verify that clicking the View Source icon again dehighlites the button and toggles the view source mode off.
3. Click in the editing pane and verify that CTRL-SHIFT-F12 toggles the view source mode on and off.
4. Verify that when in View Source mode and comment and script tag stripping is enabled, that both inputs are removed when toggled off.

# ViewSource Plugin with FullScreen Plugin details

1. The ViewSource plugin is FullScreen aware. It will should work appropriately when in full screen mode.

## Things to test:

1. Verify that while in Full Screen mode clicking the View Source icon highlights the button appropriately and toggles the view source mode on and scales appropriately.

# ViewSource Plugin with readOnly enabled details

1. The ViewSource plugin supports a readonly mode. This should display the content but not allow any edits..

## Things to test:

1. Verify that while in View Source mode, the source cannot be edited.

# ViewSource Plugin with script* disabled

1. The ViewSource plugin supports disabling the script stripping, comment stripping, etc. This can be dangerous, but sometimes it is desirable.

## Things to test:

1. Verify that typed in script tags, comments, and iframes are left in the content when view switched.

# ViewSource Plugin with stripEventHandlers enabled

## Things to test:

1. Click the view source button and verify that all on* attributes have been removed.

# ViewSource Plugin with stripEventHandlers disabled

## Things to test:

1. Click the view source button and verify that all on* attributes have NOT been removed.

# ViewSource Plugin with onmouseover in content.

foobar

## Things to test:

1. Move mouse over "foobar" and make sure alert is not displayed.

Content after the editors.